pub struct CollectionMetadata {
pub name: String,
pub shard_ids: Vec<u64>,
pub seed: u32,
pub replication: u8,
}Fields
name: Stringshard_ids: Vec<u64>seed: u32replication: u8Trait Implementations
Sourceimpl Archive for CollectionMetadata
impl Archive for CollectionMetadata
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCollectionMetadata
type Archived = ArchivedCollectionMetadata
The archived representation of this type. Read more
Sourcetype Resolver = CollectionMetadataResolver
type Resolver = CollectionMetadataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CollectionMetadata
impl Clone for CollectionMetadata
Sourcefn clone(&self) -> CollectionMetadata
fn clone(&self) -> CollectionMetadata
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectionMetadata
impl Debug for CollectionMetadata
Sourceimpl Default for CollectionMetadata
impl Default for CollectionMetadata
Sourcefn default() -> CollectionMetadata
fn default() -> CollectionMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CollectionMetadata
impl<'de> Deserialize<'de> for CollectionMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CollectionMetadata, __D> for Archived<CollectionMetadata>
impl<__D: Fallible + ?Sized> Deserialize<CollectionMetadata, __D> for Archived<CollectionMetadata>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CollectionMetadata, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CollectionMetadata, <__D as Fallible>::Error>
Deserializes using the given deserializer